==> TundereBird-0.23.tar.bz2: TundereBird-0.23/gui/Smdn.Applications.TundereBird/Smdn.Applications.TundereBird/ImapAccount.cs <==
using System;
using System.Collections.Generic;
using System.Net;

using Smdn.Net.Imap4;
using Smdn.Net.Imap4.Client;
using Smdn.Net.Imap4.WebClients;

namespace Smdn.Applications.TundereBird {
  public class ImapAccount : AccountBase {
    protected override ICredentials Credentials {
      get { return credential; }
    }

    public bool UseTlsIfAvailable {
      get; private set;
    }

    public bool ReadOnly {
      get; private set;
    }

    public Dictionary<string, string> ServerID {
      get; private set;
    }

    public ImapNamespace ServerNamespaces {
      get; private set;
    }

    public ImapCapabilityList ServerCapabilities {
      get; private set;
    }

    public string TrashMailboxName {
      get; set;
    }

    public ImapAccount(string name, Uri serverUri, string password, int timeout, bool useTlsIfAvailable, bool readOnly)
      : base(name, serverUri, timeout)
    {
      this.credential = new NetworkCredential(ImapStyleUriParser.GetUser(serverUri), password);

      this.UseTlsIfAvailable = useTlsIfAvailable;
      this.ReadOnly = readOnly;
      this.TrashMailboxName = null;
    }

    public ImapWebRequest CreateRequest(Uri requestUri, string method)
    {
      var request = CreateWebRequest(requestUri, method) as ImapWebRequest;

      request.UseTlsIfAvailable = UseTlsIfAvailable;
      request.ReadOnly = ReadOnly;

      return request;
    }

    public TResult Request<TResult>(Func<ImapWebResponse, TResult> action)
    {
      return Request(null, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, Func<ImapWebResponse, TResult> action)
    {
      return Request(requestUri, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, string method, Func<ImapWebResponse, TResult> action)
    {
      using (var response = CreateRequest(requestUri, method).GetResponse() as ImapWebResponse) {
        OnGotResponse(response);

        if (action != null)
          return action(response);
      }

      return default(TResult);
    }

    protected override void OnGotResponse(WebResponse response)
    {
      var r = response as ImapWebResponse;

      if (!serverInfoRetrieved) {
        ServerID = r.ServerID;
        ServerNamespaces = r.Namespaces;
        ServerCapabilities = r.ServerCapabilities;

        serverInfoRetrieved = true;
      }

      base.OnGotResponse(response);
    }

    private bool serverInfoRetrieved = false;
    private NetworkCredential credential;
  }
}

==> TundereBird-0.24.tar.bz2: TundereBird-0.24/gui/Smdn.Applications.TundereBird/Smdn.Applications.TundereBird/ImapAccount.cs <==
using System;
using System.Collections.Generic;
using System.Net;

using Smdn.Net.Imap4;
using Smdn.Net.Imap4.Client;
using Smdn.Net.Imap4.WebClients;

namespace Smdn.Applications.TundereBird {
  public class ImapAccount : AccountBase {
    protected override ICredentials Credentials {
      get { return credential; }
    }

    public bool UseTlsIfAvailable {
      get; private set;
    }

    public bool ReadOnly {
      get; private set;
    }

    public Dictionary<string, string> ServerID {
      get; private set;
    }

    public ImapNamespace ServerNamespaces {
      get; private set;
    }

    public ImapCapabilityList ServerCapabilities {
      get; private set;
    }

    public string TrashMailboxName {
      get; set;
    }

    public ImapAccount(string name, Uri serverUri, ICredentials credential, int timeout, bool useTlsIfAvailable, bool readOnly)
      : base(name, serverUri, timeout)
    {
      this.credential = credential;
      this.UseTlsIfAvailable = useTlsIfAvailable;
      this.ReadOnly = readOnly;
      this.TrashMailboxName = null;
    }

    public ImapWebRequest CreateRequest(Uri requestUri, string method)
    {
      var request = CreateWebRequest(requestUri, method) as ImapWebRequest;

      request.UseTlsIfAvailable = UseTlsIfAvailable;
      request.ReadOnly = ReadOnly;

      return request;
    }

    public TResult Request<TResult>(Func<ImapWebResponse, TResult> action)
    {
      return Request(null, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, Func<ImapWebResponse, TResult> action)
    {
      return Request(requestUri, null, action);
    }

    public TResult Request<TResult>(Uri requestUri, string method, Func<ImapWebResponse, TResult> action)
    {
      using (var response = CreateRequest(requestUri, method).GetResponse() as ImapWebResponse) {
        OnGotResponse(response);

        if (action != null)
          return action(response);
      }

      return default(TResult);
    }

    protected override void OnGotResponse(WebResponse response)
    {
      var r = response as ImapWebResponse;

      if (!serverInfoRetrieved) {
        ServerID = r.ServerID;
        ServerNamespaces = r.Namespaces;
        ServerCapabilities = r.ServerCapabilities;

        serverInfoRetrieved = true;
      }

      base.OnGotResponse(response);
    }

    private bool serverInfoRetrieved = false;
    private ICredentials credential;
  }
}
